pub struct UserPage {Show 22 fields
avatar: TemplateChild<Avatar>,
direct_chat_box: TemplateChild<ListBox>,
direct_chat_button: TemplateChild<LoadingButtonRow>,
verified_row: TemplateChild<ActionRow>,
verified_stack: TemplateChild<Stack>,
verify_button: TemplateChild<LoadingButton>,
room_box: TemplateChild<Box>,
room_title: TemplateChild<Label>,
membership_row: TemplateChild<ActionRow>,
membership_label: TemplateChild<Label>,
power_level_row: TemplateChild<PowerLevelSelectionRow>,
invite_button: TemplateChild<LoadingButtonRow>,
kick_button: TemplateChild<LoadingButtonRow>,
ban_button: TemplateChild<LoadingButtonRow>,
unban_button: TemplateChild<LoadingButtonRow>,
remove_messages_button: TemplateChild<LoadingButtonRow>,
ignored_row: TemplateChild<ActionRow>,
ignored_button: TemplateChild<LoadingButton>,
user: BoundObject<User>,
bindings: RefCell<Vec<Binding>>,
permissions_handler: RefCell<Option<SignalHandlerId>>,
room_handlers: RefCell<Vec<SignalHandlerId>>,
}Fields
avatar: TemplateChild<Avatar>direct_chat_box: TemplateChild<ListBox>verified_row: TemplateChild<ActionRow>verified_stack: TemplateChild<Stack>room_box: TemplateChild<Box>room_title: TemplateChild<Label>membership_row: TemplateChild<ActionRow>membership_label: TemplateChild<Label>power_level_row: TemplateChild<PowerLevelSelectionRow>ignored_row: TemplateChild<ActionRow>user: BoundObject<User>The current user.
bindings: RefCell<Vec<Binding>>permissions_handler: RefCell<Option<SignalHandlerId>>room_handlers: RefCell<Vec<SignalHandlerId>>Implementations
Sourceimpl UserPage
impl UserPage
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl UserPage
impl UserPage
Sourcefn disconnect_signals(&self)
fn disconnect_signals(&self)
Disconnect all the signals.
Sourcefn copy_user_id(&self)
fn copy_user_id(&self)
Copy the user ID to the clipboard.
Sourcefn update_direct_chat(&self)
fn update_direct_chat(&self)
Update the visibility of the direct chat button.
Sourcefn load_direct_chat(&self)
fn load_direct_chat(&self)
Load whether the current user has a direct chat or not.
Sourceasync fn open_direct_chat(&self)
async fn open_direct_chat(&self)
Open a direct chat with the current user.
If one doesn’t exist already, it is created.
Sourcefn update_room(&self)
fn update_room(&self)
Update the room section.
Sourcefn reset_room(&self)
fn reset_room(&self)
Reset the initial state of the buttons of the room section.
Sourceasync fn set_power_level(&self)
async fn set_power_level(&self)
Set the power level of the user.
Sourceasync fn invite_user(&self)
async fn invite_user(&self)
Invite the user to the room.
Sourceasync fn unban_user(&self)
async fn unban_user(&self)
Unban the room member.
Sourceasync fn remove_messages(&self)
async fn remove_messages(&self)
Remove the known events of the room member.
async fn remove_known_messages_inner( &self, room: &Room, events: Vec<OwnedEventId>, reason: Option<String>, )
Sourcefn update_verified(&self)
fn update_verified(&self)
Update the verified row.
Sourceasync fn verify_user(&self)
async fn verify_user(&self)
Launch the verification for the current user.
Sourcefn update_ignored(&self)
fn update_ignored(&self)
Update the ignored row.
Sourceasync fn toggle_ignored(&self)
async fn toggle_ignored(&self)
Toggle whether the user is ignored or not.